import React, { useState, useEffect } from 'react';
import { Modal, Card, Table, Button, Tree, Input, notification } from 'antd';

import { LoadFieldsByGroup, LoadGroup } from '@/services/platform/bs'
import { PlusOutlined, DeleteOutlined } from '@ant-design/icons';
import Sortable from 'sortablejs';
import styles from './index.less'
import { pick } from 'lodash';
import {
    ChangeOrder
} from '@/services/platform/bs'
const AddModal = props => {

    const { callBackSubmit = () => { }, type, formObj, visible } = props;
    const [loading, setLoading] = useState(false);
    const [treeLoading, setTreeLoading] = useState(true)
    const [isModalVisible, setIsModalVisible] = useState(false)
    const [data, setData] = useState([])
    const [flag, setFlag] = useState(0); // 弹窗类型
    const [pickIndex, setPickIndex] = useState('')
    const [createName, setCreateName] = useState('')
    // 提交
    const onSubmit = () => {
        setLoading(true);
        let arr = []
        data.map((item) => {
            if (item.children && item.children.length) {
                item.children.map(childrenItem => {
                    arr.push({ groupName: item.title, ID: childrenItem.key })
                })
            }
        })
        ChangeOrder(arr).then(res => {
            setLoading(false);
            if (res.msg === 'Ok' || res.msg === '') {
                notification.success({
                    message: '提示',
                    duration: 3,
                    description: '编辑成功',
                });
                callBackSubmit();
            }
            else {
                notification.error({
                    message: '提示',
                    duration: 3,
                    description: res.msg,
                });
            }
        })
    };

    useEffect(() => {
        if (type != '') {
            setTreeLoading(true)
            LoadGroup({
                tableName: formObj.tableName
            }).then(
                res => {
                    setTreeLoading(false)
                    if (res.msg === 'Ok') {
                        let arr = []
                        res.data.root.map(item => {
                            arr.push(item.text)
                        })
                        LoadFieldsByGroup({ tableName: formObj.tableName, groupName: arr.join(",") }).then(respone => {
                            if (respone.msg === 'Ok') {
                                let data = handlerDatas(respone.data.root)
                                let arr = []
                                data.map((item, index) => {
                                    arr.push({ title: item.Group, key: index, top: true })
                                    arr[index].children = []
                                    item.children.map(propTtem => {
                                        arr[index].children.push({ title: propTtem.Name, key: propTtem.ID, top: false })
                                    })
                                })

                                setData(arr)
                            }
                        })
                    }

                }
            )
        }

    }, [visible, flag]);

    const add = () => {
        setCreateName('')
        setIsModalVisible(true)
    }
    const handlerDatas = (arr) => {
        let obj = {};
        arr.forEach((item, index) => {
            let { Group } = item;
            if (!obj[Group]) {
                obj[Group] = {
                    Group,
                    children: []
                }
            }
            obj[Group].children.push(item);
        });
        return Object.values(obj); // 最终输出
    }

    //完成拖拽
    const onDrop = (info) => {
        const dropKey = info.node.props.eventKey;
        const dragKey = info.dragNode.props.eventKey;
        const dropPos = info.node.props.pos.split('-');
        const dropPosition = info.dropPosition - Number(dropPos[dropPos.length - 1]);

        const loop = (data, key, callback) => {
            for (let i = 0; i < data.length; i++) {
                if (data[i].key === key) {
                    return callback(data[i], i, data);
                }
                if (data[i].children) {
                    loop(data[i].children, key, callback);
                }
            }
        };
        const changeData = [...data];
        // Find dragObject
        let dragObj;
        if (info.dragNode.top) {
            return
        } else {
            loop(changeData, dragKey, (item, index, arr) => {
                arr.splice(index, 1);
                dragObj = item;
            });
        }


        if (!info.dropToGap) {
            // Drop on the content
            loop(data, dropKey, item => {
                item.children = item.children || [];
                // where to insert 示例添加到尾部，可以是随意位置
                item.children.push(dragObj);
            });
        }

        else if (
            !info.dragNode.top && info.node.children &&
            dropPosition === 1 // On the bottom gap
        ) {
            loop(data, dropKey, item => {
                item.children = item.children || [];
                // where to insert 示例添加到头部，可以是随意位置
                item.children.unshift(dragObj);
            });
        } else {
            let ar;
            let i;

            info.dragNode.top ? '' : loop(data, dropKey, (item, index, arr) => {
                ar = arr;
                i = index;
            });
            if (dropPosition === -1) {
                info.dragNode.top ? '' : ar.splice(i, 0, dragObj);
            } else {
                info.dragNode.top ? '' : ar.splice(i + 1, 0, dragObj);
            }
        }
        //changeData就是拖拽结束后改变的数据格式, 需要在这里重新赋值 即可显示最新拖拽之后的结果
        setData(changeData)
    };
    /**
     *
     * @param {Array} selectedKeys  选中的key 数组存放,单多选
     * @param {Node} e 被选择中的node信息,可以拿到 数据源, 层级关系等...
     */
    //完成选择
    const onSelect = (selectedKeys, e) => {
        if (e.node.top) {
            const index = data.findIndex(item => item.key === e.node.key)
            setPickIndex(index)
        }
        else {
            setPickIndex('')
        }

    }
    const del = () => {
        if (pickIndex !== '') {
            let arr = [...data]
            arr.splice(pickIndex, 1)
            setData(arr)
        }
    }
    const handleOk = () => {
        let arr = [...data]
        createName !== '' && arr.push({ title: createName, key: arr.length, top: true, children: [] })
        setData(arr)
        setIsModalVisible(false)
    }
    const handleCancel = () => {
        setIsModalVisible(false)
    }
    const change = (e) => {
        setCreateName(e.target.value)
    }
    return (
        <>
            <Modal
                title='字段配置'
                bodyStyle={{ width: '100%', minHeight: '100px' }}
                style={{ top: '50px', left: '50px' }}
                width='30%'
                destroyOnClose
                maskClosable={false}
                cancelText="取消"
                okText="确认"
                {...props}
                onOk={() => onSubmit()}
                confirmLoading={loading}
                forceRender={true}
                getContainer={false}
            >
                {visible && (
                    <div style={{ display: 'flex' }} className={styles.cardList}>
                        <Card bordered={true} extra={<div style={{ display: 'flex' }}><Button onClick={add} style={{ display: 'flex', alignItems: 'center', marginRight: '1rem' }}>添加分组<PlusOutlined /></Button><Button danger onClick={del} style={{ display: 'flex', alignItems: 'center' }}>删除分组<DeleteOutlined /></Button> </div>} style={{ width: '100%' }}>
                            <Tree
                                draggable //是否可以拖拽
                                blockNode //是否节点占据一行   
                                showLine  //    是否展示连接线
                                treeData={data} //数据源 格式 Array 每项的数据格式Object { key:..., title:...,... }
                                onDrop={onDrop} //拖拽结束后触发的回调函数
                                onSelect={onSelect} // 选中某一级的回调函数
                            />
                        </Card>


                    </div>

                )}
            </Modal>
            <Modal title="添加分组" style={{ top: '200px', left: '50px' }} visible={isModalVisible} onOk={handleOk} onCancel={handleCancel}>
                <Input
                    value={createName}
                    className="site-input-right"
                    onChange={change}
                    style={{
                        width: 400,
                    }}
                    placeholder="请输入分组名称"
                />
            </Modal>
        </>
    );
};
export default AddModal;
