import React, { useState, useEffect } from 'react';
import { Form, Modal, Input, Select, AutoComplete, Button, notification, message, Card } from 'antd';
import styles from '../dimensionsConfig.less'

import {
  GetGISServerMapList,
  publisService, GetProjectNames
} from '@/services/webConfig/api';
import {
  PlusCircleOutlined,CloseCircleOutlined 
} from '@ant-design/icons';

const { Option } = Select;
const AddModal = props => {
  const { callBackSubmit = () => { }, type, formObj, visible, solutionNames } = props;
  const [loading, setLoading] = useState(false);
  const [attributes, setAttributes] = useState([{ key: '', value: '' }])
  const [workList, setWorkList] = useState([]);
  const [allData, setAllData] = useState([]);
  const [gsIp, setGsIp] = useState([]);
  const [projectNmme, setProjectNmme] = useState([]);
  const [form] = Form.useForm();
  const { Item } = Form;
  // 提交
  const onSubmit = () => {
    form.validateFields().then(validate => {
      if (validate) {
        setLoading(true);
        let obj = form.getFieldsValue();
        if (type === 'add') {
          let query = {
            _version: 9999,
            gsIP: obj.serviceadress,
            gsPort: obj.port,
            gsAppName: obj.servicename,
            gsUser: obj.user,
            gsWorkspaceName: obj.workname,
            gsPwd: obj.password,
            serviceName: obj.name,
            solution: solutionNames,
          }
          publisService(query, { timeout: 120000 })
            .then(res => {
              setLoading(false);
              if (res.success) {
                form.resetFields();
                callBackSubmit();
                notification.success({
                  message: '提示',
                  duration: 3,
                  description: '新增成功',
                });
                setWorkList([])
                handlelocalStorage('add', obj.serviceadress, obj.servicename)
              } else {
                notification.error({
                  message: '提示',
                  duration: 3,
                  description: '新增失败',
                });
              }
            })
            .catch(err => {
              notification.error({
                message: '提示',
                duration: 3,
                description: '新增失败',
              });
              setLoading(false);
            });
        }
      }
    });
  };



  const onFinish = value => { };
  useEffect(() => {
    switch (type) {
      case 'add':
        let gsIp = [];
        let localStorageData = handlelocalStorage('get');
        if (localStorageData) {
          gsIp = localStorageData.map(item => ({
            value: item.gsIp,
            item: item.gsIp
          }));
        }
        setGsIp(gsIp)
        let localIps = ['192.168.12.7', '192.168.19.100']
        let port = localIps.includes(gsIp) ? 8080 : 8088
        form.setFieldsValue({ ...formObj, ip: '192.168.12.97' });
        break;
      case 'edit':
        form.setFieldsValue({ ...formObj });
        break;
      default:
        break;
    }
  }, [visible]);

  //存储到localstorage
  const handlelocalStorage = (type, gsIp, gisAppName) => {
    if (!localStorage) return null;
    let result = JSON.parse(localStorage.getItem('metaData'))
    if (type == 'get') {
      return result;
    }
    if (!result || !result.find(item => item.gsIp == gsIp)) {
      if (!result) result = [];
      result.push({
        gsIp,
        gisAppName: [{
          value: gisAppName,
          item: gisAppName
        }]
      })
      localStorage.setItem('metaData', JSON.stringify(result))
      return
    }
    let data = result.find(item => item.gsIp == gsIp)
    let isHasGisAppName = data.gisAppName.find(item => item.value == gisAppName);
    if (isHasGisAppName) return;
    data.gisAppName.push({
      value: gisAppName,
      item: gisAppName
    })
    localStorage.setItem('metaData', JSON.stringify(result))
  };

  const layout = {
    layout: 'horizontal',
    labelCol: {
      span: 4,
    },
    wrapperCol: {
      span: 16,
    },
  };

  const selectIp = (value) => {
    let localIps = ['192.168.12.7', '192.168.19.100']
    let port = localIps.includes(value) ? 8080 : 8088
    form.setFieldsValue({ port, serviceadress: value });

  }
  // 获取项目名
  const getProject = () => {
    const obj = form.getFieldsValue();
    if (obj.ip && obj.port) {
      GetProjectNames({ ip: obj.ip, port: obj.port }).then(res => {
        if (res.msg === 'Ok') {
          notification.success({
            message: '提示',
            duration: 3,
            description: '获取成功',
          });
          let data = Object.values(JSON.parse(res.data))
          setProjectNmme(data)
          if (data.length) {
            form.setFieldsValue({ projectName: data[0] });
            selectProject(data[0])
          }
        } else {
          notification.error({
            message: '提示',
            duration: 3,
            description: '获取失败',
          });
        }
      }).catch(e => {
        console.log('e', e);
      })
    } else {
      message.warning("未输入ip或port")
    }
  }
  const selectProject = (value) => {
    const obj = form.getFieldsValue();
    GetProjectNames({ ip: obj.ip, port: obj.port, projectname: value }).then(response => {
      let newArr = JSON.parse(response.data)
      let workArr = Object.keys(newArr.data)
      setAllData(newArr.data)
      if (workArr.length) {
        setWorkList(workArr)
        form.setFieldsValue({ name: workArr[0], type: newArr.data[workArr[0]].type });
      }

    })
  }
  const selectName = (value) => {
    form.setFieldsValue({ type: allData[value].type });
  }
  const addExtra = () => {

  }
  return (
    <Modal
      title={`${type === 'add' ? '元数据发布' : '编辑'}`}
      bodyStyle={{ width: '100%', minHeight: '100px' }}
      style={{ top: '150px' }}
      width="700px"
      destroyOnClose
      maskClosable={false}
      cancelText="取消"
      okText="确认"
      {...props}
      onOk={() => onSubmit()}
      confirmLoading={loading}
      forceRender={true}
      getContainer={false}
    >
      {visible && (
        <Form form={form} {...layout} onFinish={onFinish}>
          <Item
            label="IP"
            name="ip"
            rules={[{ required: true, message: '请选择ip地址' }]}
          >
            <AutoComplete
              placeholder="请输入IP"
              options={gsIp}
              onSelect={selectIp}

            />
          </Item>
          <Item
            label="端口"
            name="port"
            rules={[{ required: true, message: '请输入端口' }]}
          >
            <div className={styles.imgList}>
              <Input placeholder="请输入GIS服务器端口" allowClear />
              <Button style={{ marginLeft: '0.5rem' }} onClick={getProject}>获取项目名</Button>
            </div>
          </Item>
          <Item
            label="项目名"
            name="projectName"
            rules={[{ required: true, message: '请选择项目名' }]}
          >
            <Select onChange={selectProject}>
              {projectNmme.length ? projectNmme.map((item, index) => { return <Option key={index} value={item}>{item}</Option> }) : ''}
            </Select>
          </Item>
          <Item
            label="数据源名"
            name="name"
            rules={[{ required: true, message: '请选择数据源名' }]}
          >
            <Select onChange={selectName}>
              {workList.length ? workList.map((item, index) => { return <Option key={index} value={item}>{item}</Option> }) : ''}
            </Select>
          </Item>
          <Item
            label="数据类型"
            name="type"
            rules={[{ required: true, message: '请输入数据类型' }]}
          >
            <Input placeholder="请输入数据类型" allowClear disabled />
          </Item>
          <Item
            label="额外属性"
            rules={[{ required: true, message: '请输入额外属性' }]}
          >
            <Card style={{ maxHeight: '8rem', overflowY: 'scroll', padding: '0.1rem' }}>
              {attributes.length ? attributes.map((item, index) => {
                return <div className={styles.containerFileds}>
                  <Item
                    label="键"
                    name={`key${index}`}
                    style={{ width: '45%' }}
                  >
                    <Input placeholder="" allowClear />
                  </Item>
                  <Item
                    label="值"
                    name={`value${index}`}
                    style={{ width: '45%' }}
                  >
                    <Input placeholder="" allowClear />
                  </Item>
                  <CloseCircleOutlined 
                    style={{
                      fontSize: '16px', color: 'red', 
                      cursor: 'pointer',
                      lineHeight: '1.5rem'
                    }} />
                </div>
              }) : ''}
              <PlusCircleOutlined style={{
                fontSize: '16px', color: '#1890FF', position: 'absolute',
                right: '0',
                top: '0.2rem',
                cursor: 'pointer'
              }}
                onClick={addExtra} />
            </Card>
          </Item>
        </Form>
      )}
    </Modal>
  );
};
export default AddModal;
